API docs for “spamfighter.interfaces.IPartnerRegistrator”

# Class s.i.IPartnerRegistrator(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Модуль регистрации партнеров с использованием логинов и паролей.

Method | register | Регистрация нового партнера.

def register(login, password): (source)
Регистрация нового партнера.

Parameters | login | логин партнера (type: `str` )
| password | пароль партнера (type: `str` )
Returns | Deferred о завершении операции (type: `twisted.internet.defer.Deferred` )
Raises | PartnerLoginOccupiedError | такой логин уже занят (используется другим партнером)